<?php
$TRANSLATIONS = array(
"Invalid value supplied for %s" => "Ungültiger Wert für %s übermittelt",
"Saved" => "Gespeichert",
"test email settings" => "E-Mail-Einstellungen testen",
"If you received this email, the settings seem to be correct." => "Wenn Sie diese E-Mail erhalten haben, sind die Einstellungen korrekt.",
"A problem occurred while sending the e-mail. Please revisit your settings." => "Ein Problem ist beim Senden der E-Mail aufgetreten. Bitte überprüfen Sie Ihre Einstellungen.",
"Email sent" => "Email gesendet",
"You need to set your user email before being able to send test emails." => "Sie müssen Ihre Benutzer-E-Mail-Adresse setzen, bevor Sie Test-E-Mails versenden können.",
"Send mode" => "Sende-Modus",
"Encryption" => "Verschlüsselung",
"Authentication method" => "Authentifizierungsmethode",
"Unable to load list from App Store" => "Die Liste der Anwendungen im Store konnte nicht geladen werden.",
"Authentication error" => "Authentifizierungs-Fehler",
"Your full name has been changed." => "Ihr vollständiger Name ist geändert worden.",
"Unable to change full name" => "Der vollständige Name konnte nicht geändert werden",
"Group already exists" => "Die Gruppe existiert bereits",
"Unable to add group" => "Die Gruppe konnte nicht angelegt werden",
"Files decrypted successfully" => "Dateien erfolgreich entschlüsselt",
"Couldn't decrypt your files, please check your owncloud.log or ask your administrator" => "Dateien konnten nicht entschlüsselt werden, prüfen Sie bitte Ihre owncloud.log oder fragen Sie Ihren Administrator",
"Couldn't decrypt your files, check your password and try again" => "Dateien konnten nicht entschlüsselt werden, bitte prüfen Sie Ihr Passwort und versuchen Sie es erneut.",
"Encryption keys deleted permanently" => "Verschlüsselungsschlüssel dauerhaft gelöscht",
"Couldn't permanently delete your encryption keys, please check your owncloud.log or ask your administrator" => "Verschlüsselungsschlüssel konnten nicht dauerhaft gelöscht werden, prüfen Sie bitte Ihre owncloud.log oder frage Deinen Administrator",
"Couldn't remove app." => "Die App konnte nicht entfernt werden.",
"Email saved" => "E-Mail-Adresse gespeichert",
"Invalid email" => "Ungültige E-Mail-Adresse",
"Unable to delete group" => "Die Gruppe konnte nicht gelöscht werden",
"Unable to delete user" => "Der Benutzer konnte nicht gelöscht werden",
"Backups restored successfully" => "Backups erfolgreich wiederhergestellt",
"Couldn't restore your encryption keys, please check your owncloud.log or ask your administrator" => "Verschlüsselungsschlüssel konnten nicht wiederhergestellt werden, prüfen Sie bitte Ihre owncloud.log oder fragen Sie Ihren Administrator",
"Language changed" => "Sprache geändert",
"Invalid request" => "Ungültige Anforderung",
"Admins can't remove themself from the admin group" => "Administratoren können sich nicht selbst aus der admin-Gruppe löschen",
"Unable to add user to group %s" => "Der Benutzer konnte nicht zur Gruppe %s hinzugefügt werden",
"Unable to remove user from group %s" => "Der Benutzer konnte nicht aus der Gruppe %s entfernt werden",
"Couldn't update app." => "Die App konnte nicht aktualisiert werden.",
"Wrong password" => "Falsches Passwort",
"No user supplied" => "Keinen Benutzer angegeben",
"Please provide an admin recovery password, otherwise all user data will be lost" => "Bitte geben Sie ein Wiederherstellungspasswort für das Admin-Konto an, da sonst alle Benutzerdaten verloren gehen können",
"Wrong admin recovery password. Please check the password and try again." => "Falsches Wiederherstellungspasswort für das Admin-Konto. Bitte überprüfen Sie das Passwort und versuchen Sie es erneut.",
"Back-end doesn't support password change, but the users encryption key was successfully updated." => "Das Back-End unterstützt die Passwortänderung nicht, aber der Benutzerschlüssel wurde erfolgreich aktualisiert.",
"Unable to change password" => "Passwort konnte nicht geändert werden",
"Sending..." => "Sende...",
"User Documentation" => "Dokumentation für Benutzer",
"Admin Documentation" => "Dokumentation für Administratoren",
"Update to {appversion}" => "Update zu {appversion}",
"Uninstall App" => "App deinstallieren",
"Disable" => "Deaktivieren",
"Enable" => "Aktivieren",
"Please wait...." => "Bitte warten....",
"Error while disabling app" => "Beim Deaktivieren der Applikation ist ein Fehler aufgetreten",
"Error while enabling app" => "Beim Aktivieren der Applikation ist ein Fehler aufgetreten",
"Updating...." => "Update...",
"Error while updating app" => "Es ist ein Fehler während des Updates aufgetreten",
"Error" => "Fehler",
"Update" => "Update durchführen",
"Updated" => "Aktualisiert",
"Uninstalling ...." => "Deinstalliere ....",
"Error while uninstalling app" => "Fehler beim Deinstallieren der App",
"Uninstall" => "Deinstallieren",
"Select a profile picture" => "Wählen Sie ein Profilbild",
"Very weak password" => "Sehr schwaches Passwort",
"Weak password" => "Schwaches Passwort",
"So-so password" => "Passables Passwort",
"Good password" => "Gutes Passwort",
"Strong password" => "Starkes Passwort",
"Decrypting files... Please wait, this can take some time." => "Entschlüssle Dateien ... Bitte warten Sie, denn dieser Vorgang kann einige Zeit beanspruchen.",
"Delete encryption keys permanently." => "Verschlüsselungsschlüssel dauerhaft löschen.",
"Restore encryption keys." => "Verschlüsselungsschlüssel wiederherstellen.",
"Unable to delete {objName}" => "Löschen von {objName} nicht möglich",
"Error creating group" => "Fehler beim Erstellen der Gruppe",
"A valid group name must be provided" => "Ein gültiger Gruppenname muss angegeben werden",
"deleted {groupName}" => "{groupName} gelöscht",
"undo" => "rückgängig machen",
"Groups" => "Gruppen",
"Group Admin" => "Gruppenadministrator",
"Delete" => "Löschen",
"never" => "niemals",
"deleted {userName}" => "{userName} gelöscht",
"add group" => "Gruppe hinzufügen",
"A valid username must be provided" => "Es muss ein gültiger Benutzername angegeben werden",
"Error creating user" => "Beim Erstellen des Benutzers ist ein Fehler aufgetreten",
"A valid password must be provided" => "Es muss ein gültiges Passwort angegeben werden",
"Warning: Home directory for user \"{user}\" already exists" => "Warnung: Das Benutzerverzeichnis für den Benutzer  \"{user}\" existiert bereits",
"__language_name__" => "Deutsch (Förmlich: Sie)",
"Everything (fatal issues, errors, warnings, info, debug)" => "Alles (fatale Probleme, Fehler, Warnungen, Infos, Debug-Meldungen)",
"Info, warnings, errors and fatal issues" => "Infos, Warnungen, Fehler und fatale Probleme",
"Warnings, errors and fatal issues" => "Warnungen, Fehler und fatale Probleme",
"Errors and fatal issues" => "Fehler und fatale Probleme",
"Fatal issues only" => "Nur kritische Fehler",
"None" => "Keine",
"Login" => "Anmelden",
"Plain" => "Plain",
"NT LAN Manager" => "NT LAN Manager",
"SSL" => "SSL",
"TLS" => "TLS",
"Security Warning" => "Sicherheitshinweis",
"You are accessing %s via HTTP. We strongly suggest you configure your server to require using HTTPS instead." => "Sie greifen auf %s via HTTP zu. Wir empfehlen Ihnen dringend, Ihren Server so konfigurieren, dass stattdessen HTTPS verlangt wird.",
"Your data directory and your files are probably accessible from the internet. The .htaccess file is not working. We strongly suggest that you configure your webserver in a way that the data directory is no longer accessible or you move the data directory outside the webserver document root." => "Ihr Datenverzeichnis und Ihre Dateien sind möglicherweise aus dem Internet erreichbar. Die .htaccess-Datei funktioniert nicht. Wir raten Ihnen dringend, dass Sie Ihren Webserver dahingehend konfigurieren, dass Ihr Datenverzeichnis nicht länger aus dem Internet erreichbar ist, oder Sie verschieben das Datenverzeichnis außerhalb des Wurzelverzeichnisses des Webservers.",
"Setup Warning" => "Einrichtungswarnung",
"Your web server is not yet properly setup to allow files synchronization because the WebDAV interface seems to be broken." => "Ihr Web-Server ist noch nicht für eine Datei-Synchronisation konfiguriert, weil die WebDAV-Schnittstelle vermutlich defekt ist.",
"Please double check the <a href=\"%s\">installation guides</a>." => "Bitte prüfen Sie nochmals die <a href=\"%s\">Installationsanleitungen</a>.",
"PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." => "PHP ist offenbar so konfiguriert, dass PHPDoc-Blöcke in der Anweisung entfernt werden. Dadurch sind mehrere Kern-Apps nicht erreichbar.",
"This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." => "Dies wird wahrscheinlich durch Zwischenspeicher/Beschleuniger wie z.B. OPcache oder eAccelerator verursacht.",
"Database Performance Info" => "Info zur Datenbankperformance",
"SQLite is used as database. For larger installations we recommend to change this. To migrate to another database use the command line tool: 'occ db:convert-type'" => "SQLite wird als Datenbank verwendet. Für größere Installationen muss dies geändert werden. Zur Migration in eine andere Datenbank muss der Komandozeilenbefehl: 'occ db:convert-type' verwendet werden.",
"Module 'fileinfo' missing" => "Das Modul 'fileinfo' fehlt",
"The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." => "Das PHP-Modul 'fileinfo' fehlt. Wir empfehlen Ihnen dieses Modul zu aktivieren, um die besten Resultate bei der Bestimmung der Dateitypen zu erzielen.",
"Your PHP version is outdated" => "Ihre PHP-Version ist veraltet",
"Your PHP version is outdated. We strongly recommend to update to 5.3.8 or newer because older versions are known to be broken. It is possible that this installation is not working correctly." => "Ihre PHP-Version ist veraltet. Wir empfehlen dringend auf die Version 5.3.8 oder neuer zu aktualisieren, da ältere Versionen kompromittiert werden können. Es ist möglich, dass diese Installation nicht richtig funktioniert.",
"Locale not working" => "Die Lokalisierung funktioniert nicht",
"System locale can not be set to a one which supports UTF-8." => "Systemgebietsschema kann nicht auf eine UTF-8 unterstützende eingestellt werden.",
"This means that there might be problems with certain characters in file names." => "Dies bedeutet, dass Probleme mit bestimmten Zeichen in den Dateinamen geben kann.",
"We strongly suggest to install the required packages on your system to support one of the following locales: %s." => "Wir empfehlen dringend, die erforderlichen Pakete auf Ihrem System zu installieren, damit eine der folgenden Gebietsschemas unterstützt wird: %s.",
"Internet connection not working" => "Keine Internetverbindung",
"This server has no working internet connection. This means that some of the features like mounting of external storage, notifications about updates or installation of 3rd party apps don´t work. Accessing files from remote and sending of notification emails might also not work. We suggest to enable internet connection for this server if you want to have all features." => "Dieser Server hat keine funktionierende Internetverbindung. Dies bedeutet, dass einige Funktionen wie z.B. das Einbinden von externen Speichern, Update-Benachrichtigungen oder die Installation von Drittanbieter-Apps nicht funktionieren. Der Fernzugriff auf Dateien und das Versenden von Mail-Benachrichtigungen funktionieren eventuell ebenfalls nicht. Wir empfehlen die Internetverbindung für diesen Server zu aktivieren, wenn Sie alle Funktionen nutzen wollen.",
"Cron" => "Cron",
"Last cron was executed at %s." => "Letzter Cron wurde um %s ausgeführt.",
"Last cron was executed at %s. This is more than an hour ago, something seems wrong." => "Letzter Cron wurde um %s ausgeführt. Dies ist mehr als eine Stunde her, möglicherweise liegt ein Fehler vor.",
"Cron was not executed yet!" => "Cron wurde bis jetzt noch nicht ausgeführt!",
"Execute one task with each page loaded" => "Eine Aufgabe bei jedem Laden der Seite ausführen",
"cron.php is registered at a webcron service to call cron.php every 15 minutes over http." => "cron.php ist als Webcron-Dienst registriert, der die cron.php alle 15 Minuten per HTTP aufruft.",
"Use system's cron service to call the cron.php file every 15 minutes." => "Benutzen Sie den System-Crondienst, um die cron.php alle 15 Minuten aufzurufen.",
"Sharing" => "Teilen",
"Allow apps to use the Share API" => "Anwendungen erlauben, die Share-API zu benutzen",
"Allow users to share via link" => "Erlaube Nutzern, mithilfe von Links zu teilen",
"Enforce password protection" => "Passwortschutz erzwingen",
"Allow public uploads" => "Öffentliches Hochladen erlauben",
"Set default expiration date" => "Setze  Ablaufdatum",
"Expire after " => "Ablauf nach ",
"days" => "Tagen",
"Enforce expiration date" => "Ablaufdatum erzwingen",
"Allow resharing" => "Erlaube Weiterverteilen",
"Restrict users to only share with users in their groups" => "Nutzer nur auf das Teilen in ihren Gruppen beschränken",
"Allow users to send mail notification for shared files" => "Benutzern erlauben Mail-Benachrichtigungen für freigegebene Dateien zu senden",
"Exclude groups from sharing" => "Gruppen von Freigaben ausschließen",
"These groups will still be able to receive shares, but not to initiate them." => "Diese Gruppen können weiterhin Freigaben empfangen, aber selbst keine mehr initiieren.",
"Security" => "Sicherheit",
"Enforce HTTPS" => "HTTPS erzwingen",
"Forces the clients to connect to %s via an encrypted connection." => "Zwingt die clientseitigen Anwendungen, verschlüsselte Verbindungen zu %s herzustellen.",
"Please connect to your %s via HTTPS to enable or disable the SSL enforcement." => "Bitte verbinden Sie sich zu Ihrem %s über HTTPS um die SSL-Erzwingung zu aktivieren oder zu deaktivieren.",
"Email Server" => "E-Mail-Server",
"This is used for sending out notifications." => "Dies wird für das Senden von Benachrichtigungen verwendet.",
"From address" => "Absender-Adresse",
"mail" => "Mail",
"Authentication required" => "Authentifizierung benötigt",
"Server address" => "Adresse des Servers",
"Port" => "Port",
"Credentials" => "Zugangsdaten",
"SMTP Username" => "SMTP Benutzername",
"SMTP Password" => "SMTP Passwort",
"Test email settings" => "E-Mail-Einstellungen testen",
"Send email" => "E-Mail senden",
"Log" => "Log",
"Log level" => "Log-Level",
"More" => "Mehr",
"Less" => "Weniger",
"Version" => "Version",
"Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." => "Entwickelt von der <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud-Community</a>. Der <a href=\"https://github.com/owncloud\" target=\"_blank\">Quellcode</a> ist unter der <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a> lizenziert.",
"Add your App" => "Fügen Sie Ihre Anwendung hinzu",
"More Apps" => "Weitere Anwendungen",
"Select an App" => "Wählen Sie eine Anwendung aus",
"Documentation:" => "Dokumentation:",
"See application page at apps.owncloud.com" => "Weitere Anwendungen finden Sie auf apps.owncloud.com",
"See application website" => "Siehe Anwendungs-Website",
"<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>" => "<span class=\"licence\"></span>-lizenziert von <span class=\"author\"></span>",
"Enable only for specific groups" => "Nur für spezifizierte Gruppen aktivieren",
"All" => "Alle",
"Administrator Documentation" => "Dokumentation für Administratoren",
"Online Documentation" => "Online-Dokumentation",
"Forum" => "Forum",
"Bugtracker" => "Bugtracker",
"Commercial Support" => "Kommerzieller Support",
"Get the apps to sync your files" => "Installieren Sie die Anwendungen, um Ihre Dateien zu synchronisieren",
"Show First Run Wizard again" => "Den Einrichtungsassistenten erneut anzeigen",
"You have used <strong>%s</strong> of the available <strong>%s</strong>" => "Sie verwenden <strong>%s</strong> der verfügbaren <strong>%s</strong>",
"Password" => "Passwort",
"Your password was changed" => "Ihr Passwort wurde geändert.",
"Unable to change your password" => "Das Passwort konnte nicht geändert werden",
"Current password" => "Aktuelles Passwort",
"New password" => "Neues Passwort",
"Change password" => "Passwort ändern",
"Full Name" => "Vollständiger Name",
"Email" => "E-Mail",
"Your email address" => "Ihre E-Mail-Adresse",
"Fill in an email address to enable password recovery and receive notifications" => "Geben Sie eine E-Mail-Adresse an, um eine Wiederherstellung des Passworts zu ermöglichen und Benachrichtigungen zu empfangen",
"Profile picture" => "Profilbild",
"Upload new" => "Neues hochladen",
"Select new from Files" => "Neues aus Dateien wählen",
"Remove image" => "Bild entfernen",
"Either png or jpg. Ideally square but you will be able to crop it." => "Entweder PNG oder JPG. Im Idealfall quadratisch, aber Sie können es zuschneiden.",
"Your avatar is provided by your original account." => "Ihr Avatar wird von Ihrerem ursprünglichenKonto verwendet.",
"Cancel" => "Abbrechen",
"Choose as profile image" => "Als Profilbild wählen",
"Language" => "Sprache",
"Help translate" => "Helfen Sie bei der Übersetzung",
"The encryption app is no longer enabled, please decrypt all your files" => "Die Verschlüsselungsanwendung ist nicht länger aktiv, bitte entschlüsseln Sie alle ihre Daten",
"Log-in password" => "Login-Passwort",
"Decrypt all Files" => "Alle Dateien entschlüsseln",
"Your encryption keys are moved to a backup location. If something went wrong you can restore the keys. Only delete them permanently if you are sure that all files are decrypted correctly." => "Ihre Verschlüsselungsschlüssel wiederherstellen wurden zu einem Backup-Speicherort verschoben. Wenn irgendetwas schief läuft können die Schlüssel wiederhergestellt werden. Löschen Sie diese nur dann dauerhaft, wenn Sie sich sicher sind, dass alle Dateien korrekt entschlüsselt wurden.",
"Restore Encryption Keys" => "Verschlüsselungsschlüssel wiederherstellen",
"Delete Encryption Keys" => "Verschlüsselungsschlüssel löschen",
"Login Name" => "Loginname",
"Create" => "Erstellen",
"Admin Recovery Password" => "Admin-Passwort-Wiederherstellung",
"Enter the recovery password in order to recover the users files during password change" => "Geben Sie das Wiederherstellungspasswort ein, um die Benutzerdateien während Passwortänderung wiederherzustellen",
"Search Users and Groups" => "Nutzer und Gruppen suchen",
"Add Group" => "Gruppe hinzufügen",
"Group" => "Gruppe",
"Everyone" => "Jeder",
"Admins" => "Administratoren",
"Default Quota" => "Standard-Quota",
"Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" => "Bitte Speicherkontingent eingeben (z.B.: \"512 MB\" oder \"12 GB\")",
"Unlimited" => "Unbegrenzt",
"Other" => "Andere",
"Username" => "Benutzername",
"Quota" => "Quota",
"Storage Location" => "Speicherort",
"Last Login" => "Letzte Anmeldung",
"change full name" => "Vollständigen Namen ändern",
"set new password" => "Neues Passwort setzen",
"Default" => "Standard",
"If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwritewebroot\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" => "Wenn sich Ihre Installation nicht im Wurzelverzeichnis der Domain befindet und Cron aus dem System genutzt wird, kann es zu Fehlern bei der URL-Generierung kommen. Um dies zu verhindern, setzen Sie bitte die \"overwritewebroot\"-Option in Ihrer config.php auf das Web-Wurzelverzeichnis Ihrer Installation (Vorschlag: \"%s\").",
"URL generation in notification emails" => "URL-Generierung in Mail-Benachrichtungen",
"Connectivity Checks" => "Verbindungsüberprüfungen",
"No problems found" => "Keine Probleme gefunden",
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
